summaryrefslogtreecommitdiff
path: root/chacha_simd.cpp
diff options
context:
space:
mode:
authorJeffrey Walton <noloader@gmail.com>2019-10-26 22:11:49 -0400
committerGitHub <noreply@github.com>2019-10-26 22:11:49 -0400
commitfa39314b7a64cdf6d5a0a89b95bf26d29344c624 (patch)
treea32f443f3c436fcb5334fc82069c20bf8eef611c /chacha_simd.cpp
parent1bfb8760bb8f8b971c88aaf8d48b5731641cdd6c (diff)
downloadcryptopp-git-fa39314b7a64cdf6d5a0a89b95bf26d29344c624.tar.gz
Add XLC 12 loads and stores for AIX (PR #907)
Add XLC 12 loads and stores for AIX
Diffstat (limited to 'chacha_simd.cpp')
-rw-r--r--chacha_simd.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/chacha_simd.cpp b/chacha_simd.cpp
index ac9b8a7d..dabdbe1e 100644
--- a/chacha_simd.cpp
+++ b/chacha_simd.cpp
@@ -211,7 +211,7 @@ inline __m128i RotateLeft<16>(const __m128i val)
#if (CRYPTOPP_ALTIVEC_AVAILABLE)
// ChaCha_OperateKeystream_POWER8 is optimized for POWER7. However, Altivec
// is supported by using vec_ld and vec_st, and using a composite VecAdd
// that supports 64-bit element adds. vec_ld and vec_st add significant
// overhead when memory is not aligned. Despite the drawbacks Altivec
@@ -825,7 +825,7 @@ void ChaCha_OperateKeystream_SSE2(const word32 *state, const byte* input, byte *
#endif // CRYPTOPP_SSE2_INTRIN_AVAILABLE
-#if (CRYPTOPP_POWER8_AVAILABLE || CRYPTOPP_ALTIVEC_AVAILABLE)
+#if (CRYPTOPP_POWER7_AVAILABLE || CRYPTOPP_ALTIVEC_AVAILABLE)
// ChaCha_OperateKeystream_CORE will use either POWER7 or ALTIVEC,
// depending on the flags used to compile this source file. The
@@ -1094,11 +1094,11 @@ inline void ChaCha_OperateKeystream_CORE(const word32 *state, const byte* input,
VecStore32LE(output + 15*16, r3_3);
}
-#endif // CRYPTOPP_POWER8_AVAILABLE || CRYPTOPP_ALTIVEC_AVAILABLE
+#endif // CRYPTOPP_POWER7_AVAILABLE || CRYPTOPP_ALTIVEC_AVAILABLE
-#if (CRYPTOPP_POWER8_AVAILABLE)
+#if (CRYPTOPP_POWER7_AVAILABLE)
-void ChaCha_OperateKeystream_POWER8(const word32 *state, const byte* input, byte *output, unsigned int rounds)
+void ChaCha_OperateKeystream_POWER7(const word32 *state, const byte* input, byte *output, unsigned int rounds)
{
ChaCha_OperateKeystream_CORE(state, input, output, rounds);
}
@@ -211,7 +211,7 @@ inline __m128i RotateLeft<16>(const __m128i val)
#if (CRYPTOPP_ALTIVEC_AVAILABLE)
-// ChaCha_OperateKeystream_POWER8 is optimized for POWER7. However, Altivec
+// ChaCha_OperateKeystream_POWER7 is optimized for POWER7. However, Altivec
// is supported by using vec_ld and vec_st, and using a composite VecAdd
// that supports 64-bit element adds. vec_ld and vec_st add significant